#if defined _activity_history_included
	#endinput
#endif
#define _activity_history_included

enum AH_Event:
{
	AH_OnClientAuthorized = 0,
	AH_OnNewDayHasCome,
	AH_OnConnectionStateChanged,
	
	AH_EventCount
}

typeset AH_CB
{
	/////////////////////////
	//	AH_Event
	/////////////////////////
	
	/**
	 *	AH_OnClientAuthorized
	 *
	 *	@descr				Игрок (не бот) авторизован. AH_IsClientAuthorized начинает возвращать true.
	 *	@note				Во время смены карты авторизация не теряется.
	 */
	function void (int client);
	 
	/**
	 *	AH_OnNewDayHasCome
	 *
	 *	@descr				Наступил новый день.
	 *
	 *	@param day_number	Номер нового дня (1 = понедельник, 7 = воскресенье).
	 *
	 *	@param old_d		Прошлый день.
	 *	@param old_m		Прошлый месяц.
	 *	@param old_y		Прошлый год.
	 *
	 *	@param new_d		Новый   день.
	 *	@param new_m		Новый   месяц.
	 *	@param new_y		Новый   год.
	 */
	function void (int day_number, int old_d, int old_m, int old_y, int new_d, int new_m, int new_y);
	
	/**
	 *	AH_OnConnectionStateChanged
	 *
	 *	@descr				Состояние MYSQL соединения изменено.
	 *	@param connected	true = соединение установлено/восстановлено. false = потеряно.
	 */
	function void (bool connected);
	
	/////////////////////////
	// NATIVE
	/////////////////////////
	
	/**
	 *	AH_GetActivityTimeForPeriod
	 *
	 *	@descr				Время активности игрока за определённый период.
	 *	
	 *	@param client		Индекс игрока (не бот) (владелец @param account_id), или 0. Возможно не авторизован (AH_IsClientAuthorized). Возможно меняется карта (IsClientInGame).
	 *	@param account_id	GetSteamAccountID.
	 *
	 *	@param seconds		Сколько секунд игрок провёл в команде за указанный период:
	 *						seconds[0] = игрок ещё не выбрал команду, после входа на сервер.
	 *						seconds[1] = SPEC.
	 *						seconds[2] = T.
	 *						seconds[3] = CT.
	 *
	 *	@param data			Переданные данные или 0.
	 */
	function void (int client, int account_id, const int seconds[4], any data);
	
	/**
	 *	AH_GetActivityTopForPeriod
	 *
	 *	@descr				ТОП активности в определённой команде за определённый период.
	 *
	 *	@note				Кол-во вызовов функции (1 гарантирован) = кол-ву игроков в топе.
	 *						Вызывается по очереди в порядке возрастания (1 место в топе, 2, 3 и т.д.).
	 *						Сортировка зависит от @param teamFlags.
	 *						Если @param place[0] == place[1], или в функции произошла ошибка, то вызовов уже не будет.
	 *	
	 *	@param account_id	GetSteamAccountID топ игрока.
	 *	@param name			Имя топ игрока.
	 *	@param place[2]		place[0] = место в топе (0 = топ пуст). place[1] = игроков в топе (от 0 до @param places, 0 = топ пуст).
	 *
	 *	@param seconds		Сколько секунд игрок провёл в команде за указанный период:
	 *						seconds[0] = игрок ещё не выбрал команду, после входа на сервер.
	 *						seconds[1] = SPEC.
	 *						seconds[2] = T.
	 *						seconds[3] = CT.
	 *
	 *	@param data			Переданные данные или 0.
	 */
	function void (int account_id, char[] name, const int place[2], const int seconds[4], any data);
}

native void AH_HookEvent(AH_Event event, AH_CB callback);
native void AH_UnhookEvent(AH_Event event, AH_CB callback);

/**
 *	@return				Дескриптор подключения к базе данных (MYSQL) или null.
 */
native Database AH_GetDatabase();

native bool AH_IsClientAuthorized(int client);

/**
 *	Узнать время активности игрока за определённый период.
 *
 *	@param account_id	GetSteamAccountID. Неважно онлайн игрок или нет, как и неважно авторизован он или нет.
 *
 *	@param sPeriod		Период:
 *						"20.1.2022-21.1.2022" 	с 20 по 21 января (включительно).
 *						"1.05.2022" 			1 мая.
 *						NULL_STRING 			за всё время.
 *
 *	@param callback		Функция-результат.
 *	@param data			Передать данные в @param callback.
 */
native void AH_GetActivityTimeForPeriod(int account_id, const char[] sPeriod, AH_CB callback, any data=0);

/////

#define FL_TEAM_X 		(1 << 0) // Команда не выбрана.
#define FL_TEAM_SPEC 	(1 << 1) // Наблюдатель.
#define FL_TEAM_T 		(1 << 2) // Террорист.
#define FL_TEAM_CT 		(1 << 3) // Контр-Террорист.
#define FL_TEAM_ALL 	(1 << 4) // Все команды.

/**
 *	Получить ТОП активности в определённой команде за определённый период.
 *
 *	@param sPeriod		Период:
 *						"20.1.2022-21.1.2022" 	с 20 по 21 января (включительно).
 *						"1.05.2022" 			1 мая.
 *						NULL_STRING 			за всё время.
 *
 *	@param teamFlags	Влияет на сортировку. Секунды в каких командах (FL_TEAM_..) суммируются?
 *	@param places		Максимум игроков в топе (0 = без лимита).
 *	@param callback		Функция-результат.
 *	@param data			Передать данные в @param callback.
 */
native void AH_GetActivityTopForPeriod(const char[] sPeriod, int teamFlags, int places, AH_CB callback, any data=0);

/////

/**
 *	Узнать время активности игрока в текущей сессии.
 *
 *	@note				Во время смены карты сессия/авторизация не прерываются.
 *	@param client		Индекс авторизованного (AH_OnClientAuthorized/AH_IsClientAuthorized) игрока.
 *
 *	@param seconds		Сколько секунд игрок провёл в команде в текущей сессии:
 *						seconds[0] = игрок ещё не выбрал команду, после входа на сервер.
 *						seconds[1] = SPEC.
 *						seconds[2] = T.
 *						seconds[3] = CT.
 *
 *	@return				true = информация успешно получена.
 */
native bool AH_GetActivityTimePerSession(int client, int seconds[4]);

public SharedPlugin __pl_activity_history = 
{
	name = "activity_history",	/* Имя библиотеки */
	file = "activity_history.smx",
	required = 0				/* Не требуется, т.к. включается с задержкой (позже обычных .smx). */
};

public void __pl_activity_history_SetNTVOptional()
{
	MarkNativeAsOptional("AH_HookEvent");
	MarkNativeAsOptional("AH_UnhookEvent");
	
	MarkNativeAsOptional("AH_GetDatabase");
	MarkNativeAsOptional("AH_IsClientAuthorized");
	
	MarkNativeAsOptional("AH_GetActivityTimeForPeriod");
	MarkNativeAsOptional("AH_GetActivityTopForPeriod");
	MarkNativeAsOptional("AH_GetActivityTimePerSession");
}

/* 

/////

#undef  REQUIRE_PLUGIN
// https://world-source.ru/hueco_mundo/activity_history_config.zip
#include <activity_history>
#define REQUIRE_PLUGIN

static const char	  g_sActivityHistoryLib[] = "activity_history";
bool	g_bActivityHistoryLib = false;

public void OnAllPluginsLoaded() {
	if (LibraryExists(g_sActivityHistoryLib)) {
		OnActivityHistoryAdded(true );
	}
}
public void OnLibraryAdded	(const char[] name) {
	if (!strcmp(name, g_sActivityHistoryLib)) {
		OnActivityHistoryAdded(true );
	}
}
public void OnLibraryRemoved(const char[] name) {
	if (!strcmp(name, g_sActivityHistoryLib)) {
		OnActivityHistoryAdded(false);
	}
}
static void OnActivityHistoryAdded(bool added) {
	if (g_bActivityHistoryLib != added) {
		if ((g_bActivityHistoryLib = added)) {
			AH_HookEvent(..
		}
		else{
			
		}
	}
}

/////

*/